/**************************************************************************//**
*   @file   ad5791.h
*   @brief  Header file of AD5791 Driver for Microblaze processor.
*   @author ATofan (alexandru.tofan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 468
******************************************************************************/
#ifndef _AD5791_H_
#define _AD5791_H_
#ifdef AD5791_GLOBALS
    #define AD5791_EXT extern volatile
#else
    #define AD5791_EXT volatile
#endif
 
/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "xil_types.h"
#include "xparameters.h"

/*****************************************************************************/
/* Types Declarations                                                        */
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
    char            chData;
    unsigned char   uchData;
    short           siData;
    unsigned short  usiData;
    int             iData;
    unsigned int    uiData;
    float           fData;
}uCProbeDataUnion;

/*****************************************************************************/
/* AD5791                                                                    */
/*****************************************************************************/
#define AD5791_CMD_WR_DAC               1
#define AD5791_CMD_WR_CTRL              2
#define AD5791_CND_WR_CLR_CODE          3
#define AD5791_CMD_WR_SOFT_CTRL         4
#define AD5791_CMD_RD_DAC               9
#define AD5791_CMD_RD_CTRL              10
#define AD5791_CMD_RD_CLR_CODE          11
#define AD5791_CMD_POSITION             20
#define AD5791_DAC_DATA_POSITION        0
#define AD5791_CLR_CODE_DATA_POSITION   0
#define CTRL_LIN_COMP                   (12 << 6)
#define CTRL_SDODIS                     (1 << 5)
#define CTRL_BIN2SC                     (1 << 4)
#define CTRL_DACTRI                     (1 << 3)
#define CTRL_OPGND                      (1 << 2)
#define CTRL_RBUF                       (1 << 1)
#define SOFT_CTRL_RESET                 (1 << 2)
#define SOFT_CTRL_CLR                   (1 << 1)
#define SOFT_CTRL_LDAC                  (1 << 0)

/*****************************************************************************/
/* SPI Configuration                                                         */
/*****************************************************************************/
#define AD5791_SPI      XPAR_AXI_SPORT_0_BASEADDR

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
AD5791_EXT uCProbeDataUnion AD5791_Data[21];    //used to store the values for uC-Probe communication

/*****************************************************************************/
/*  Functions Prototypes                                                     */
/*****************************************************************************/
int     AD5791_Init( void );                        // Initialize the board and SPI communication
int     AD5791_UpdateParameters(void);              // Communicate with the device and update needed values
void    AD5791_SetDacC2( int DACValue );            // Set the value of DAC register using two's complement coding
void    AD5791_SetDacBO( int DACValue );            // Set the value of DAC register using binary offset coding
void    AD5791_SetClrCode( int ClrCodeValue );      // Set the value of Clear Code register
void    AD5791_SetSoftCtrl( int SoftCtrlValue );    // Set the value of Software control register
int     AD5791_GetDac( void );                      // Read the value of DAC register
int     AD5791_GetCtrl( void );                     // Read the value of Control register
int     AD5791_GetClrCode( void );                  // Read the value of Clear Code register
int     AD5791_Set( int *iValue );                  // Send command via SPI
int     AD5791_Get( void );                         // Receive value via SPI
float   AD5791_SetGet( void );                      // Interpret and return
void    AD5791_SetLed( void );                      // Set LED's in uC/Probe GUI
#endif /* _AD5791_H_ */
